==> com.liferay.knowledge.base.api-17.0.0-sources.jar: com/liferay/knowledge/base/configuration/KBGroupServiceConfiguration.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.knowledge.base.configuration;

import aQute.bnd.annotation.metatype.Meta;

import com.liferay.portal.configuration.metatype.annotations.ExtendedObjectClassDefinition;

/**
 * @author Roberto Díaz
 */
@ExtendedObjectClassDefinition(
	category = "knowledge-base",
	scope = ExtendedObjectClassDefinition.Scope.GROUP
)
@Meta.OCD(
	id = "com.liferay.knowledge.base.configuration.KBGroupServiceConfiguration",
	localization = "content/Language",
	name = "knowledge-base-group-service-configuration-name"
)
public interface KBGroupServiceConfiguration {

	@Meta.AD(deflt = "ckeditor", name = "get-editor-name", required = false)
	public String getEditorName();

	@Meta.AD(
		deflt = "true", name = "article-increment-priority-enabled",
		required = false
	)
	public boolean articleIncrementPriorityEnabled();

	@Meta.AD(
		deflt = ".markdown|.md", name = "markdown-importer-article-extensions",
		required = false
	)
	public String[] markdownImporterArticleExtensions();

	@Meta.AD(
		deflt = "intro.markdown", name = "markdown-importer-article-intro",
		required = false
	)
	public String markdownImporterArticleIntro();

	@Meta.AD(
		deflt = ".bmp|.gif|.jpeg|.jpg|.png",
		name = "markdown-importer-image-file-extensions", required = false
	)
	public String[] markdownImporterImageFileExtensions();

	@Meta.AD(
		deflt = "/images", name = "markdown-importer-image-folder",
		required = false
	)
	public String markdownImporterImageFolder();

	@Meta.AD(deflt = "false", name = "source-url-enabled", required = false)
	public boolean sourceURLEnabled();

	@Meta.AD(
		deflt = "edit-on-github", name = "source-url-edit-message-key",
		required = false
	)
	public String sourceURLEditMessageKey();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/admin.email.from.name}",
		name = "email-from-name", required = false
	)
	public String emailFromName();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/admin.email.from.address}",
		name = "email-from-address", required = false
	)
	public String emailFromAddress();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-added-enabled",
		required = false
	)
	public boolean emailKBArticleAddedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_added_subject.tmpl}",
		name = "email-kb-article-added-subject", required = false
	)
	public String emailKBArticleAddedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_added_body.tmpl}",
		name = "email-kb-article-added-body", required = false
	)
	public String emailKBArticleAddedBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-updated-enabled",
		required = false
	)
	public boolean emailKBArticleUpdatedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_updated_subject.tmpl}",
		name = "email-kb-article-updated-subject", required = false
	)
	public String emailKBArticleUpdatedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_updated_body.tmpl}",
		name = "email-kb-article-updated-body", required = false
	)
	public String emailKBArticleUpdatedBody();

	@Meta.AD(
		deflt = "true",
		name = "email-kb-article-suggestion-in-progress-enabled",
		required = false
	)
	public boolean emailKBArticleSuggestionInProgressEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_in_progress_subject.tmpl}",
		name = "email-kb-article-suggestion-in-progress-subject",
		required = false
	)
	public String emailKBArticleSuggestionInProgressSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_in_progress_body.tmpl}",
		name = "email-kb-article-suggestion-in-progress-body", required = false
	)
	public String emailKBArticleSuggestionInProgressBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-suggestion-received-enabled",
		required = false
	)
	public boolean emailKBArticleSuggestionReceivedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_received_subject.tmpl}",
		name = "email-kb-article-suggestion-received-subject", required = false
	)
	public String emailKBArticleSuggestionReceivedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_received_body.tmpl}",
		name = "email-kb-article-suggestion-received-body", required = false
	)
	public String emailKBArticleSuggestionReceivedBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-suggestion-resolved-enabled",
		required = false
	)
	public boolean emailKBArticleSuggestionResolvedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_resolved_subject.tmpl}",
		name = "email-kb-article-suggestion-resolved-subject", required = false
	)
	public String emailKBArticleSuggestionResolvedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_resolved_body.tmpl}",
		name = "email-kb-article-suggestion-resolved-body", required = false
	)
	public String emailKBArticleSuggestionResolvedBody();

	@Meta.AD(deflt = "true", name = "enable-rss", required = false)
	public boolean enableRss();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/search.container.page.default.delta}",
		name = "rss-delta", required = false
	)
	public String rssDelta();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/rss.feed.display.style.default}",
		name = "rss-display-style", required = false
	)
	public String rssDisplayStyle();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/rss.feed.type.default}",
		name = "rss-feed-type", required = false
	)
	public String rssFeedType();

}

==> com.liferay.knowledge.base.api-20.3.0-sources.jar: com/liferay/knowledge/base/configuration/KBGroupServiceConfiguration.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.knowledge.base.configuration;

import aQute.bnd.annotation.metatype.Meta;

import com.liferay.portal.configuration.metatype.annotations.ExtendedObjectClassDefinition;

/**
 * @author Roberto Díaz
 */
@ExtendedObjectClassDefinition(
	category = "knowledge-base",
	scope = ExtendedObjectClassDefinition.Scope.GROUP
)
@Meta.OCD(
	id = "com.liferay.knowledge.base.configuration.KBGroupServiceConfiguration",
	localization = "content/Language",
	name = "knowledge-base-group-service-configuration-name"
)
public interface KBGroupServiceConfiguration {

	@Meta.AD(deflt = "ckeditor", name = "get-editor-name", required = false)
	public String getEditorName();

	@Meta.AD(
		deflt = "true", name = "article-increment-priority-enabled",
		required = false
	)
	public boolean articleIncrementPriorityEnabled();

	@Meta.AD(
		deflt = ".markdown|.md", name = "markdown-importer-article-extensions",
		required = false
	)
	public String[] markdownImporterArticleExtensions();

	@Meta.AD(
		deflt = "intro.markdown", name = "markdown-importer-article-intro",
		required = false
	)
	public String markdownImporterArticleIntro();

	@Meta.AD(
		deflt = ".bmp|.gif|.jpeg|.jpg|.png",
		name = "markdown-importer-image-file-extensions", required = false
	)
	public String[] markdownImporterImageFileExtensions();

	@Meta.AD(
		deflt = "/images", name = "markdown-importer-image-folder",
		required = false
	)
	public String markdownImporterImageFolder();

	@Meta.AD(deflt = "false", name = "source-url-enabled", required = false)
	public boolean sourceURLEnabled();

	@Meta.AD(
		deflt = "edit-on-github", name = "source-url-edit-message-key",
		required = false
	)
	public String sourceURLEditMessageKey();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/admin.email.from.name}",
		name = "email-from-name", required = false
	)
	public String emailFromName();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/admin.email.from.address}",
		name = "email-from-address", required = false
	)
	public String emailFromAddress();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-added-enabled",
		required = false
	)
	public boolean emailKBArticleAddedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_added_subject.tmpl}",
		name = "email-kb-article-added-subject", required = false
	)
	public String emailKBArticleAddedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_added_body.tmpl}",
		name = "email-kb-article-added-body", required = false
	)
	public String emailKBArticleAddedBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-updated-enabled",
		required = false
	)
	public boolean emailKBArticleUpdatedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_updated_subject.tmpl}",
		name = "email-kb-article-updated-subject", required = false
	)
	public String emailKBArticleUpdatedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_updated_body.tmpl}",
		name = "email-kb-article-updated-body", required = false
	)
	public String emailKBArticleUpdatedBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-review-enabled",
		required = false
	)
	public boolean emailKBArticleReviewEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_review_subject.tmpl}",
		name = "email-kb-article-review-subject", required = false
	)
	public String emailKBArticleReviewSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_review_body.tmpl}",
		name = "email-kb-article-review-body", required = false
	)
	public String emailKBArticleReviewBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-expired-enabled",
		required = false
	)
	public boolean emailKBArticleExpiredEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_expired_subject.tmpl}",
		name = "email-kb-article-expired-subject", required = false
	)
	public String emailKBArticleExpiredSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_article_expired_body.tmpl}",
		name = "email-kb-article-expired-body", required = false
	)
	public String emailKBArticleExpiredBody();

	@Meta.AD(
		deflt = "true",
		name = "email-kb-article-suggestion-in-progress-enabled",
		required = false
	)
	public boolean emailKBArticleSuggestionInProgressEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_in_progress_subject.tmpl}",
		name = "email-kb-article-suggestion-in-progress-subject",
		required = false
	)
	public String emailKBArticleSuggestionInProgressSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_in_progress_body.tmpl}",
		name = "email-kb-article-suggestion-in-progress-body", required = false
	)
	public String emailKBArticleSuggestionInProgressBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-suggestion-received-enabled",
		required = false
	)
	public boolean emailKBArticleSuggestionReceivedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_received_subject.tmpl}",
		name = "email-kb-article-suggestion-received-subject", required = false
	)
	public String emailKBArticleSuggestionReceivedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_received_body.tmpl}",
		name = "email-kb-article-suggestion-received-body", required = false
	)
	public String emailKBArticleSuggestionReceivedBody();

	@Meta.AD(
		deflt = "true", name = "email-kb-article-suggestion-resolved-enabled",
		required = false
	)
	public boolean emailKBArticleSuggestionResolvedEnabled();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_resolved_subject.tmpl}",
		name = "email-kb-article-suggestion-resolved-subject", required = false
	)
	public String emailKBArticleSuggestionResolvedSubject();

	@Meta.AD(
		deflt = "${resource:com/liferay/knowledge/base/dependencies/email_kb_suggestion_resolved_body.tmpl}",
		name = "email-kb-article-suggestion-resolved-body", required = false
	)
	public String emailKBArticleSuggestionResolvedBody();

	@Meta.AD(deflt = "true", name = "enable-rss", required = false)
	public boolean enableRss();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/search.container.page.default.delta}",
		name = "rss-delta", required = false
	)
	public String rssDelta();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/rss.feed.display.style.default}",
		name = "rss-display-style", required = false
	)
	public String rssDisplayStyle();

	@Meta.AD(
		deflt = "${server-property://com.liferay.portal/rss.feed.type.default}",
		name = "rss-feed-type", required = false
	)
	public String rssFeedType();

}
